;; Generated package description from tempel.el  -*- no-byte-compile: t -*-
(define-package "tempel" "1.1" "Tempo templates/snippets with in-buffer field editing" '((emacs "27.1") (compat "29.1.4.4")) :commit "bcc3185202edce67c7f7fc74287cc2ecbeef10c6" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("abbrev" "languages" "tools" "text") :url "https://github.com/minad/tempel")
